#pragma once

// get a pointer to the environ variable
char **get_environ();
